@@ -1,6 +1,6 @@
 import os,time,string,random
 
-from src.print.custom_prints import *
+from src.print.anim_print import *
 def clear_console(type="line"):
     if type == "line":
         print(100*" ",end="\r")
